trouble-host

Crates

git

Versions

default

Flavors

PairingFailedReason

Enum PairingFailedReason 

pub enum PairingFailedReason {
Show 17 variants Success, PasskeyEntryFailed, OobNotAvailable, AuthenticationRequirements, ConfirmValueFailed, PairingNotSupported, EncryptionKeySize, CommandNotSupported, UnspecifiedReason, RepeatedAttempts, InvalidParameters, DHKeyCheckFailed, NumericComparisonFailed, BrEdrPairingInProgress, GenerationNotAllowed, KeyRejected, Busy,
}
Pairing Failed Reason

Variants



Success

Pairing success



PasskeyEntryFailed

The user input of passkey failed, for example, the user cancelled the operation.



OobNotAvailable

The OOB data is not available.



AuthenticationRequirements

The pairing procedure cannot be performed as authentication requirements cannot be met due to IO capabilities of one or both devices.



ConfirmValueFailed

The confirm value does not match the calculated compare value.



PairingNotSupported

Pairing is not supported by the device.



EncryptionKeySize

The resultant encryption key size is not long enough for the security requirements of this device.



CommandNotSupported

The SMP command received is not supported on this device.



UnspecifiedReason

Pairing failed due to an unspecified reason.



RepeatedAttempts

Pairing or authentication procedure is disallowed because too little time has elapsed since last pairing request or security request.



InvalidParameters

The Invalid Parameters error code indicates that the command length is invalid or that a parameter is outside of the specified range.



DHKeyCheckFailed

Indicates to the remote device that the DHKey Check value received doesn’t match the one calculated by the local device.



NumericComparisonFailed

Indicates that the confirm values in the numeric comparison protocol do not match.



BrEdrPairingInProgress

Indicates that the pairing over the LE transport failed due to a Pairing Request sent over the BR/EDR transport in progress.



GenerationNotAllowed

Indicates that the BR/EDR Link Key generated on the BR/EDR transport cannot be used to derive and distribute keys for the LE transport or the LE LTK generated on the LE transport cannot be used to derive a key for the BR/EDR transport.



KeyRejected

Indicates that the device chose not to accept a distributed key.



Busy

Indicates that the device is not ready to perform a pairing procedure.