pub struct HostResources<C: Controller, P: PacketPool, const CONNS: usize, const CHANNELS: usize, const ADV_SETS: usize = 1, const BONDS: usize = 10> { /* private fields */ }Expand description
HostResources holds the resources used by the host.
The l2cap packet pool is used by the host to handle inbound data, by allocating space for incoming packets and dispatching to the appropriate connection and channel.
Implementations
Sourceimpl<C: Controller, P: PacketPool, const CONNS: usize, const CHANNELS: usize, const ADV_SETS: usize, const BONDS: usize> HostResources<C, P, CONNS, CHANNELS, ADV_SETS, BONDS>
impl<C: Controller, P: PacketPool, const CONNS: usize, const CHANNELS: usize, const ADV_SETS: usize, const BONDS: usize> HostResources<C, P, CONNS, CHANNELS, ADV_SETS, BONDS>