pub struct Identity {
pub addr: Address,
}Expand description
Identity of a peer device
Sometimes we have to save both the address and the IRK. Because sometimes the peer uses the static or public address even though the IRK is sent. In this case, the IRK exists but the used address is not RPA.
Fields
addr: AddressIdentity address (random static or public)
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn match_address(&self, address: &Address) -> bool
pub fn match_address(&self, address: &Address) -> bool
Check whether the address matches the identity.
Matches if the address is an exact match (kind + addr) or if the IRK can resolve it.
Sourcepub fn match_identity(&self, identity: &Identity) -> bool
pub fn match_identity(&self, identity: &Identity) -> bool
Check whether the given identity matches current identity