trouble-host

Crates

git

Versions

default

Flavors

IdentityResolvingKey

Struct IdentityResolvingKey 

#[repr(transparent)]
pub struct IdentityResolvingKey(pub NonZeroU128);
Identity Resolving Key.

Tuple Fields

0: NonZeroU128

Implementations

Source

impl IdentityResolvingKey

pub const fn new(k: u128) -> Option<Self>

Creates an Identity Resolving Key from a u128 value.

pub const fn from_le_bytes(k: [u8; 16]) -> Option<Self>

Creates an Identity Resolving Key from a [u8; 16] value in little endian.

pub const fn to_le_bytes(self) -> [u8; 16]

Returns the Identity Resolving Key as [u8; 16] value in little endian.

pub fn generate_resolvable_address<T: RngCore + CryptoRng>( &self, rng: &mut T, ) -> [u8; 6]

Generates a resolvable private address using this key.

The generated address follows the format described in Bluetooth Core Specification [Vol 3] Part C, Section 10.8.2.

pub fn resolve_address(&self, address: &BdAddr) -> bool

Resolves a resolvable private address.

Returns true if the address was generated using this IRK.