trouble-host

Crates

git

Versions

default

Flavors

SecurityCmds

Trait SecurityCmds 

pub trait SecurityCmds:
    Controller
    + ControllerCmdSync<LeLongTermKeyRequestReply>
    + ControllerCmdAsync<LeEnableEncryption>
    + ControllerCmdSync<LeAddDeviceToResolvingList>
    + ControllerCmdSync<LeRemoveDeviceFromResolvingList>
    + ControllerCmdSync<LeClearResolvingList>
    + ControllerCmdSync<LeSetAddrResolutionEnable>
    + ControllerCmdSync<LeSetResolvablePrivateAddrTimeout>
    + ControllerCmdSync<LeSetPrivacyMode> { }
Trait for security-related controller commands.

When the security feature is enabled, this requires the controller to support encryption, resolving list and address resolution HCI commands. When disabled, this is automatically implemented for all controllers.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors