#[repr(transparent)]pub struct IdentityResolvingKey(pub NonZeroU128);Expand description
Identity Resolving Key.
Tuple Fields
0: NonZeroU128Implementations
Sourceimpl IdentityResolvingKey
impl IdentityResolvingKey
Sourcepub const fn from_le_bytes(k: [u8; 16]) -> Option<Self>
pub const fn from_le_bytes(k: [u8; 16]) -> Option<Self>
Creates an Identity Resolving Key from a [u8; 16] value in little endian.
Sourcepub const fn to_le_bytes(self) -> [u8; 16]
pub const fn to_le_bytes(self) -> [u8; 16]
Returns the Identity Resolving Key as [u8; 16] value in little endian.
Sourcepub fn generate_resolvable_address<T: RngCore + CryptoRng>(
&self,
rng: &mut T,
) -> [u8; 6]
pub fn generate_resolvable_address<T: RngCore + CryptoRng>( &self, rng: &mut T, ) -> [u8; 6]
Generates a resolvable private address using this key.
The generated address follows the format described in Bluetooth Core Specification [Vol 3] Part C, Section 10.8.2.
Sourcepub fn resolve_address(&self, address: &BdAddr) -> bool
pub fn resolve_address(&self, address: &BdAddr) -> bool
Resolves a resolvable private address.
Returns true if the address was generated using this IRK.