trouble-host

Crates

git

Versions

default

Flavors

Stack

Struct Stack 

pub struct Stack<'stack, C, P: PacketPool> { /* private fields */ }
Contains the host stack

Implementations

Source

impl<'stack, C: Controller, P: PacketPool> Stack<'stack, C, P>

pub fn runner(&self) -> Runner<'_, C, P>

Obtain a Runner to drive the BLE host.

The runner must be polled (e.g. via Runner::run()) to drive the BLE host.

pub fn central(&self) -> Central<'_, C, P>

Obtain a Central handle for the central BLE role.

This is a lightweight handle that can be created multiple times. Concurrent connect operations are serialized internally.

pub fn peripheral(&self) -> Peripheral<'_, C, P>

Obtain a Peripheral handle for the peripheral BLE role.

This is a lightweight handle that can be created multiple times. Concurrent advertise operations are serialized internally.

pub async fn command<T>( &self, cmd: T, ) -> Result<T::Return, BleHostError<C::Error>>
where T: SyncCmd, C: ControllerCmdSync<T>,

Run a HCI command and return the response.

pub async fn async_command<T>( &self, cmd: T, ) -> Result<(), BleHostError<C::Error>>
where T: AsyncCmd, C: ControllerCmdAsync<T>,

Run an async HCI command where the response will generate an event later.

pub async fn read_minimum_supported_connection_interval( &self, ) -> Result<<LeReadMinimumSupportedConnectionInterval as SyncCmd>::Return, BleHostError<C::Error>>

Read the minimum supported connection interval from the controller.

pub fn metrics<F: FnOnce(&HostMetrics) -> R, R>(&self, f: F) -> R

Read current host metrics

pub fn log_status(&self, verbose: bool)

Log status information of the host

pub fn get_connection_by_peer_address( &self, peer_address: Address, ) -> Option<Connection<'_, P>>

Get a connection by its peer address

pub fn get_connected_handle( &self, handle: ConnHandle, ) -> Option<Connection<'_, P>>

Get a connection by its handle

pub fn connections(&self) -> ConnectedIter<'_, P>

Iterate over all currently connected connections.